package com.ruoyi.manage.service.impl;

import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.manage.domain.StaffManage;
import com.ruoyi.manage.mapper.StaffManageMapper;
import com.ruoyi.manage.service.IStaffManageService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * 人员管理Service业务层处理
 * 
 * @author boman
 * @date 2025-05-07
 */
@Service
public class StaffManageServiceImpl implements IStaffManageService 
{
    @Autowired
    private StaffManageMapper staffManageMapper;

    /**
     * 查询人员管理
     * 
     * @param staffId 人员管理主键
     * @return 人员管理
     */
    @Override
    public StaffManage selectStaffManageByStaffId(Long staffId)
    {
        return staffManageMapper.selectStaffManageByStaffId(staffId);
    }

    /**
     * 查询人员管理列表
     * 
     * @param staffManage 人员管理
     * @return 人员管理
     */
    @Override
    public List<StaffManage> selectStaffManageList(StaffManage staffManage)
    {
        return staffManageMapper.selectStaffManageList(staffManage);
    }

    /**
     * 新增人员管理
     * 
     * @param staffManage 人员管理
     * @return 结果
     */
    @Override
    public int insertStaffManage(StaffManage staffManage)
    {
        staffManage.setCreateTime(DateUtils.getNowDate());
        return staffManageMapper.insertStaffManage(staffManage);
    }

    /**
     * 修改人员管理
     * 
     * @param staffManage 人员管理
     * @return 结果
     */
    @Override
    public int updateStaffManage(StaffManage staffManage)
    {
        staffManage.setUpdateTime(DateUtils.getNowDate());
        return staffManageMapper.updateStaffManage(staffManage);
    }

    /**
     * 批量删除人员管理
     * 
     * @param staffIds 需要删除的人员管理主键
     * @return 结果
     */
    @Override
    public int deleteStaffManageByStaffIds(Long[] staffIds)
    {
        return staffManageMapper.deleteStaffManageByStaffIds(staffIds);
    }

    /**
     * 删除人员管理信息
     * 
     * @param staffId 人员管理主键
     * @return 结果
     */
    @Override
    public int deleteStaffManageByStaffId(Long staffId)
    {
        return staffManageMapper.deleteStaffManageByStaffId(staffId);
    }
}
